Learn R Programming

wasim (version 1.1.1)

bias: Calculate objective functions between two vectors

Description

The function calculates the bias between two time series

Usage

bias(a, b, cond = rep(TRUE, NROW(a)))
rmse(a, b, cond = rep(TRUE, NROW(a)))
mean_error(a, b, cond = rep(TRUE, NROW(a)))

Arguments

a
First vector
b
Second vector
cond
Vector of boolean, indicating which cases to exclude

Value

  • The method describes a scalar the bias between the vectors